# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLockerkastMerk(KeuzelijstField):
    """Het merk van de lockerkast."""
    naam = 'KlLockerkastMerk'
    label = 'Lockerkast merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLockerkastMerk'
    definition = 'Het merk van de lockerkast.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLockerkastMerk'
    options = {
        'inox-rvs': KeuzelijstWaarde(invulwaarde='inox-rvs',
                                     label='INOX-RVS',
                                     status='ingebruik',
                                     definitie='INOX-RVS',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLockerkastMerk/inox-rvs')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlSchakelkettingFabrikant import KlSchakelkettingFabrikant
from otlmow_model.Datatypes.KlSchakelkettingMateriaal import KlSchakelkettingMateriaal
from otlmow_model.Datatypes.KwantWrdInMegaPascal import KwantWrdInMegaPascal, KwantWrdInMegaPascalWaarden
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Schakelketting(AIMNaamObject, PuntGeometrie):
    """Een schakelketting bestaat uit een reeks met elkaar verbonden schakels. Ze worden doorgaans gebruikt om trekkrachten uit te oefenen, zoals bv. bij hijsinstallaties."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hijsinstallatie')

        self._breedteSchakel = OTLAttribuut(field=KwantWrdInMillimeter,
                                            naam='breedteSchakel',
                                            label='breedte schakel',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.breedteSchakel',
                                            definition='De breedte van één schakel van de ketting. Indien de schakel ovaalvormig is, gaat het dus om de kleinste diameter van de ovaal.',
                                            owner=self)

        self._dikteSchakel = OTLAttribuut(field=KwantWrdInMillimeter,
                                          naam='dikteSchakel',
                                          label='dikte schakel',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.dikteSchakel',
                                          definition='De dikte van één schakel van de ketting.',
                                          owner=self)

        self._fabrikant = OTLAttribuut(field=KlSchakelkettingFabrikant,
                                       naam='fabrikant',
                                       label='fabrikant',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.fabrikant',
                                       definition='De fabrikant of producent van de ketting.',
                                       owner=self)

        self._hoogteSchakel = OTLAttribuut(field=KwantWrdInMillimeter,
                                           naam='hoogteSchakel',
                                           label='hoogte schakel',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.hoogteSchakel',
                                           definition='De hoogte van één schakel van de ketting. Indien de schakel ovaalvormig is, gaat het dus om de grootste diameter van de ovaal.',
                                           owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.lengte',
                                    definition='De totale lengte van de ketting.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlSchakelkettingMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.materiaal',
                                       definition='het materiaal waaruit de schakels van de kettings vervaardigd zijn.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.technischeFiche',
                                             definition='De technische fiche van de ketting. Deze bevat ten minste een detailtekening van één schakel en va de ketting als geheel.',
                                             owner=self)

        self._treksterkte = OTLAttribuut(field=KwantWrdInMegaPascal,
                                         naam='treksterkte',
                                         label='treksterkte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakelketting.treksterkte',
                                         definition='De treksterkte van een ketting is de maximale trekkracht die de ketting aan kan.',
                                         owner=self)

    @property
    def breedteSchakel(self) -> KwantWrdInMillimeterWaarden:
        """De breedte van één schakel van de ketting. Indien de schakel ovaalvormig is, gaat het dus om de kleinste diameter van de ovaal."""
        return self._breedteSchakel.get_waarde()

    @breedteSchakel.setter
    def breedteSchakel(self, value):
        self._breedteSchakel.set_waarde(value, owner=self)

    @property
    def dikteSchakel(self) -> KwantWrdInMillimeterWaarden:
        """De dikte van één schakel van de ketting."""
        return self._dikteSchakel.get_waarde()

    @dikteSchakel.setter
    def dikteSchakel(self, value):
        self._dikteSchakel.set_waarde(value, owner=self)

    @property
    def fabrikant(self) -> str:
        """De fabrikant of producent van de ketting."""
        return self._fabrikant.get_waarde()

    @fabrikant.setter
    def fabrikant(self, value):
        self._fabrikant.set_waarde(value, owner=self)

    @property
    def hoogteSchakel(self) -> KwantWrdInMillimeterWaarden:
        """De hoogte van één schakel van de ketting. Indien de schakel ovaalvormig is, gaat het dus om de grootste diameter van de ovaal."""
        return self._hoogteSchakel.get_waarde()

    @hoogteSchakel.setter
    def hoogteSchakel(self, value):
        self._hoogteSchakel.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van de ketting."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """het materiaal waaruit de schakels van de kettings vervaardigd zijn."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de ketting. Deze bevat ten minste een detailtekening van één schakel en va de ketting als geheel."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def treksterkte(self) -> KwantWrdInMegaPascalWaarden:
        """De treksterkte van een ketting is de maximale trekkracht die de ketting aan kan."""
        return self._treksterkte.get_waarde()

    @treksterkte.setter
    def treksterkte(self, value):
        self._treksterkte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWentellagerType(KeuzelijstField):
    """Keuzelijst voor de verschillende soorten wentellager."""
    naam = 'KlWentellagerType'
    label = 'Wentellager type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWentellagerType'
    definition = 'Keuzelijst voor de verschillende soorten wentellager.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWentellagerType'
    options = {
        'bollager': KeuzelijstWaarde(invulwaarde='bollager',
                                     label='bollager',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/bollager'),
        'cilinderlager': KeuzelijstWaarde(invulwaarde='cilinderlager',
                                          label='cilinderlager',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/cilinderlager'),
        'diabololager': KeuzelijstWaarde(invulwaarde='diabololager',
                                         label='diabololager',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/diabololager'),
        'kegellager': KeuzelijstWaarde(invulwaarde='kegellager',
                                       label='kegellager',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/kegellager'),
        'kogellager': KeuzelijstWaarde(invulwaarde='kogellager',
                                       label='kogellager',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/kogellager'),
        'naaldlager': KeuzelijstWaarde(invulwaarde='naaldlager',
                                       label='naaldlager',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/naaldlager'),
        'tonlager': KeuzelijstWaarde(invulwaarde='tonlager',
                                     label='tonlager',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWentellagerType/tonlager')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMotorsturingType(KeuzelijstField):
    """Lijst met types van motorsturingen"""
    naam = 'KlMotorsturingType'
    label = 'Types motorsturing'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMotorsturingType'
    definition = 'Lijst met types van motorsturingen'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMotorsturingType'
    options = {
        'dc-motorsturing': KeuzelijstWaarde(invulwaarde='dc-motorsturing',
                                            label='DC motorsturing',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMotorsturingType/dc-motorsturing'),
        'frequentiesturing': KeuzelijstWaarde(invulwaarde='frequentiesturing',
                                              label='frequentiesturing',
                                              status='ingebruik',
                                              definitie='Elektronische vermogenschakelaar die een bepaalde uitgangsspanning met een bepaalde frequentie realiseert. Deze frequentie is onder andere bepalend voor snelheid/toerental van de elektromotor.',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMotorsturingType/frequentiesturing'),
        'softstarter': KeuzelijstWaarde(invulwaarde='softstarter',
                                        label='softstarter',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMotorsturingType/softstarter')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAflsuitingType(KeuzelijstField):
    """Het type van een afsluiting"""
    naam = 'KlAflsuitingType'
    label = 'Afsluiting type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAflsuitingType'
    definition = 'Het type van een afsluiting'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAflsuitingType'
    options = {
        'draad': KeuzelijstWaarde(invulwaarde='draad',
                                  label='Draad',
                                  status='ingebruik',
                                  definitie='Draad',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAflsuitingType/draad'),
        'hekwerk': KeuzelijstWaarde(invulwaarde='hekwerk',
                                    label='Hekwerk',
                                    status='ingebruik',
                                    definitie='Hekwerk',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAflsuitingType/hekwerk'),
        'panelen': KeuzelijstWaarde(invulwaarde='panelen',
                                    label='Panelen',
                                    status='ingebruik',
                                    definitie='Panelen',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAflsuitingType/panelen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlRiemType(KeuzelijstField):
    """Keuzelijst voor het type riem."""
    naam = 'KlRiemType'
    label = 'Riem type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlRiemType'
    definition = 'Keuzelijst voor het type riem.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlRiemType'
    options = {
        'getande-riem': KeuzelijstWaarde(invulwaarde='getande-riem',
                                         label='getande riem',
                                         status='ingebruik',
                                         definitie='getande riem',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRiemType/getande-riem'),
        'platte-riem': KeuzelijstWaarde(invulwaarde='platte-riem',
                                        label='platte riem',
                                        status='ingebruik',
                                        definitie='platte riem',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRiemType/platte-riem'),
        'v-riem': KeuzelijstWaarde(invulwaarde='v-riem',
                                   label='V-riem',
                                   status='ingebruik',
                                   definitie='V-riem',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRiemType/v-riem')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToegangsprocedureToegangstijden(KeuzelijstField):
    """De mogelijke toegangstijden bij een toegangsprocedure."""
    naam = 'KlToegangsprocedureToegangstijden'
    label = 'Toegangsprocedure toegangstijden'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlToegangsprocedureToegangstijden'
    definition = 'De mogelijke toegangstijden bij een toegangsprocedure.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToegangsprocedureToegangstijden'
    options = {
        '24-7': KeuzelijstWaarde(invulwaarde='24-7',
                                 label='24/7',
                                 status='ingebruik',
                                 definitie='24/7',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureToegangstijden/24-7'),
        'op-afspraak': KeuzelijstWaarde(invulwaarde='op-afspraak',
                                        label='op afspraak',
                                        status='ingebruik',
                                        definitie='op afspraak',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureToegangstijden/op-afspraak'),
        'tijdens-kantooruren': KeuzelijstWaarde(invulwaarde='tijdens-kantooruren',
                                                label='tijdens kantooruren',
                                                status='ingebruik',
                                                definitie='tijdens kantooruren',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureToegangstijden/tijdens-kantooruren')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Koppeling(AIMNaamObject, PuntGeometrie):
    """Een koppeling is een machineonderdeel dat wordt gebruikt om vermogen (rotatie en koppel) over te brengen van een aandrijvende as naar een aangedreven as."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koppeling'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#PompGroep')



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlServicePrioriteit(KeuzelijstField):
    """Het prioriteitsniveau dat aangeeft hoe dringend iets moet onderhouden/gerepareerd worden"""
    naam = 'KlServicePrioriteit'
    label = 'Serviceprioriteit'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlServicePrioriteit'
    definition = 'Het prioriteitsniveau dat aangeeft hoe dringend iets moet onderhouden/gerepareerd worden'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlServicePrioriteit'
    options = {
        'niet-prioritair': KeuzelijstWaarde(invulwaarde='niet-prioritair',
                                            label='niet prioritair',
                                            status='ingebruik',
                                            definitie='niet prioritair',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlServicePrioriteit/niet-prioritair'),
        'prioritair': KeuzelijstWaarde(invulwaarde='prioritair',
                                       label='prioritair',
                                       status='ingebruik',
                                       definitie='prioritair',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlServicePrioriteit/prioritair')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMotorbeveiligingType(KeuzelijstField):
    """Types voor toestellen voor motorbeveiliging volgens de toegepaste techniek."""
    naam = 'KlMotorbeveiligingType'
    label = 'Motorbeveiliging type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMotorbeveiligingType'
    definition = 'Types voor toestellen voor motorbeveiliging volgens de toegepaste techniek.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMotorbeveiligingType'
    options = {
        'koppelcontrole': KeuzelijstWaarde(invulwaarde='koppelcontrole',
                                           label='koppelcontrole',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMotorbeveiligingType/koppelcontrole'),
        'magnetisch': KeuzelijstWaarde(invulwaarde='magnetisch',
                                       label='magnetisch',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMotorbeveiligingType/magnetisch'),
        'thermisch': KeuzelijstWaarde(invulwaarde='thermisch',
                                      label='thermisch',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMotorbeveiligingType/thermisch')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTankMateriaal(KeuzelijstField):
    """Het materiaal waaruit de tank vervaardigd is."""
    naam = 'KlTankMateriaal'
    label = 'Tank materiaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTankMateriaal'
    definition = 'Het materiaal waaruit de tank vervaardigd is.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTankMateriaal'
    options = {
        'composiet': KeuzelijstWaarde(invulwaarde='composiet',
                                      label='Composiet',
                                      status='ingebruik',
                                      definitie='Composiet',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankMateriaal/composiet'),
        'kunststof': KeuzelijstWaarde(invulwaarde='kunststof',
                                      label='Kunststof',
                                      status='ingebruik',
                                      definitie='Kunststof',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankMateriaal/kunststof'),
        'metaal': KeuzelijstWaarde(invulwaarde='metaal',
                                   label='Metaal',
                                   status='ingebruik',
                                   definitie='Metaal',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankMateriaal/metaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAansluitingDamwandBestaandeConstructie(KeuzelijstField):
    """De aansluiting van de damwand op een bestaande constructie."""
    naam = 'KlAansluitingDamwandBestaandeConstructie'
    label = 'Aansluiting damwand bestaande constructie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAansluitingDamwandBestaandeConstructie'
    definition = 'De aansluiting van de damwand op een bestaande constructie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAansluitingDamwandBestaandeConstructie'
    options = {
        'door-middel-van-betonprop': KeuzelijstWaarde(invulwaarde='door-middel-van-betonprop',
                                                      label='door middel van betonprop',
                                                      status='ingebruik',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingDamwandBestaandeConstructie/door-middel-van-betonprop'),
        'door-middel-van-groutprop': KeuzelijstWaarde(invulwaarde='door-middel-van-groutprop',
                                                      label='door middel van groutprop',
                                                      status='ingebruik',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingDamwandBestaandeConstructie/door-middel-van-groutprop'),
        'door-middel-van-kleiprop': KeuzelijstWaarde(invulwaarde='door-middel-van-kleiprop',
                                                     label='door middel van kleiprop',
                                                     status='ingebruik',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingDamwandBestaandeConstructie/door-middel-van-kleiprop'),
        'door-middel-van-vrijzittend-slot': KeuzelijstWaarde(invulwaarde='door-middel-van-vrijzittend-slot',
                                                             label='door middel van vrijzittend slot',
                                                             status='ingebruik',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingDamwandBestaandeConstructie/door-middel-van-vrijzittend-slot')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToegangsprocedureBijlageType(KeuzelijstField):
    """De bijlagetypes van een toegangsprocedure."""
    naam = 'KlToegangsprocedureBijlageType'
    label = 'Bijlagetype toegangsprocedure'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlToegangsprocedureBijlageType'
    definition = 'De bijlagetypes van een toegangsprocedure.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToegangsprocedureBijlageType'
    options = {
        'aanvraagformulier': KeuzelijstWaarde(invulwaarde='aanvraagformulier',
                                              label='aanvraagformulier',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/aanvraagformulier'),
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='andere',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/andere'),
        'handleiding': KeuzelijstWaarde(invulwaarde='handleiding',
                                        label='handleiding',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/handleiding'),
        'noodprocedure': KeuzelijstWaarde(invulwaarde='noodprocedure',
                                          label='noodprocedure',
                                          status='ingebruik',
                                          definitie='noodprocedure',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/noodprocedure'),
        'parkeergelegenheid': KeuzelijstWaarde(invulwaarde='parkeergelegenheid',
                                               label='parkeergelegenheid',
                                               status='ingebruik',
                                               definitie='parkeergelegenheid',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/parkeergelegenheid'),
        'reglement': KeuzelijstWaarde(invulwaarde='reglement',
                                      label='reglement',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/reglement'),
        'routebeschrijving': KeuzelijstWaarde(invulwaarde='routebeschrijving',
                                              label='routebeschrijving',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/routebeschrijving'),
        'veiligheidsvoorschriften': KeuzelijstWaarde(invulwaarde='veiligheidsvoorschriften',
                                                     label='veiligheidsvoorschriften',
                                                     status='ingebruik',
                                                     definitie='veiligheidsvoorschriften',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureBijlageType/veiligheidsvoorschriften')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNoodstopknopMerk(KeuzelijstField):
    """Het merk van een noodstopknop."""
    naam = 'KlNoodstopknopMerk'
    label = 'Noodstopknop merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNoodstopknopMerk'
    definition = 'Het merk van een noodstopknop.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNoodstopknopMerk'
    options = {
        'isotron': KeuzelijstWaarde(invulwaarde='isotron',
                                    label='ISOTRON',
                                    status='ingebruik',
                                    definitie='ISOTRON',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNoodstopknopMerk/isotron'),
        'phoenics': KeuzelijstWaarde(invulwaarde='phoenics',
                                     label='Phoenics',
                                     status='uitgebruik',
                                     definitie='Phoenix',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNoodstopknopMerk/phoenics'),
        'phoenix': KeuzelijstWaarde(invulwaarde='phoenix',
                                    label='Phoenix',
                                    status='ingebruik',
                                    definitie='Phoenix',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNoodstopknopMerk/phoenix'),
        'pilz': KeuzelijstWaarde(invulwaarde='pilz',
                                 label='PILZ',
                                 status='ingebruik',
                                 definitie='PILZ',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNoodstopknopMerk/pilz')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTankKleur(KeuzelijstField):
    """De kleur van de tank."""
    naam = 'KlTankKleur'
    label = 'Tank kleur'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTankKleur'
    definition = 'De kleur van de tank.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTankKleur'
    options = {
        'blauw': KeuzelijstWaarde(invulwaarde='blauw',
                                  label='Blauw',
                                  status='ingebruik',
                                  definitie='Blauw',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/blauw'),
        'bruin': KeuzelijstWaarde(invulwaarde='bruin',
                                  label='Bruin',
                                  status='ingebruik',
                                  definitie='Bruin',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/bruin'),
        'grijs': KeuzelijstWaarde(invulwaarde='grijs',
                                  label='Grijs',
                                  status='ingebruik',
                                  definitie='Grijs',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/grijs'),
        'groen': KeuzelijstWaarde(invulwaarde='groen',
                                  label='Groen',
                                  status='ingebruik',
                                  definitie='Groen',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/groen'),
        'paars': KeuzelijstWaarde(invulwaarde='paars',
                                  label='Paars',
                                  status='ingebruik',
                                  definitie='Paars',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/paars'),
        'rood': KeuzelijstWaarde(invulwaarde='rood',
                                 label='Rood',
                                 status='ingebruik',
                                 definitie='Rood',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/rood'),
        'wit': KeuzelijstWaarde(invulwaarde='wit',
                                label='Wit',
                                status='ingebruik',
                                definitie='Wit',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/wit'),
        'zwart': KeuzelijstWaarde(invulwaarde='zwart',
                                  label='Zwart',
                                  status='ingebruik',
                                  definitie='Zwart',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTankKleur/zwart')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlFlensType(KeuzelijstField):
    """Keuzelijst met de types flensen."""
    naam = 'KlFlensType'
    label = 'Flens type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlFlensType'
    definition = 'Keuzelijst met de types flensen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlFlensType'
    options = {
        'blindflens': KeuzelijstWaarde(invulwaarde='blindflens',
                                       label='blindflens',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFlensType/blindflens'),
        'overschuifflens': KeuzelijstWaarde(invulwaarde='overschuifflens',
                                            label='overschuifflens',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFlensType/overschuifflens'),
        'vlakkelasflens': KeuzelijstWaarde(invulwaarde='vlakkelasflens',
                                           label='vlakkelasflens',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFlensType/vlakkelasflens'),
        'voorlasflens': KeuzelijstWaarde(invulwaarde='voorlasflens',
                                         label='voorlasflens',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFlensType/voorlasflens')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSlotvullingDamwand(KeuzelijstField):
    """De vulling van het slot van de damwand."""
    naam = 'KlSlotvullingDamwand'
    label = 'Slotvulling damwand'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSlotvullingDamwand'
    definition = 'De vulling van het slot van de damwand.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSlotvullingDamwand'
    options = {
        'bitumineuze': KeuzelijstWaarde(invulwaarde='bitumineuze',
                                        label='Bitumineuze',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotvullingDamwand/bitumineuze'),
        'gelaste': KeuzelijstWaarde(invulwaarde='gelaste',
                                    label='Gelaste',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotvullingDamwand/gelaste'),
        'zonder-voegvulling': KeuzelijstWaarde(invulwaarde='zonder-voegvulling',
                                               label='Zonder voegvulling',
                                               status='ingebruik',
                                               definitie='Zonder voegvulling',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotvullingDamwand/zonder-voegvulling'),
        'zwellende': KeuzelijstWaarde(invulwaarde='zwellende',
                                      label='Zwellende',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSlotvullingDamwand/zwellende')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeSleutel(KeuzelijstField):
    """De verschillende sleuteltypes."""
    naam = 'KlTypeSleutel'
    label = 'Type sleutel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlTypeSleutel'
    definition = 'De verschillende sleuteltypes.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeSleutel'
    options = {
        'dom': KeuzelijstWaarde(invulwaarde='dom',
                                label='DOM',
                                status='ingebruik',
                                definitie='DOM',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeSleutel/dom'),
        'extern': KeuzelijstWaarde(invulwaarde='extern',
                                   label='extern',
                                   status='ingebruik',
                                   definitie='extern',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeSleutel/extern'),
        'specifiek': KeuzelijstWaarde(invulwaarde='specifiek',
                                      label='specifiek',
                                      status='ingebruik',
                                      definitie='specifiek',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeSleutel/specifiek'),
        'yale-5': KeuzelijstWaarde(invulwaarde='yale-5',
                                   label='Yale 5',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeSleutel/yale-5')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlContactpuntMerk(KeuzelijstField):
    """Lijst van merknamen van contactpunten volgens de fabrikant."""
    naam = 'KlContactpuntMerk'
    label = 'Merknamen contactpunten'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlContactpuntMerk'
    definition = 'Lijst van merknamen van contactpunten volgens de fabrikant.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlContactpuntMerk'
    options = {
        'heinen': KeuzelijstWaarde(invulwaarde='heinen',
                                   label='Heinen',
                                   status='ingebruik',
                                   definitie='Heinen',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlContactpuntMerk/heinen'),
        'locinox': KeuzelijstWaarde(invulwaarde='locinox',
                                    label='LOCINOX',
                                    status='ingebruik',
                                    definitie='LOCINOX',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlContactpuntMerk/locinox')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToestelventilatorFilterdoekKlasse(KeuzelijstField):
    """Keuzelijst die de verschillende filterklasses van een filterdoek voor een toestelventilator bevat."""
    naam = 'KlToestelventilatorFilterdoekKlasse'
    label = 'Toestelventilator filterdoek klasse'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlToestelventilatorFilterdoekKlasse'
    definition = 'Keuzelijst die de verschillende filterklasses van een filterdoek voor een toestelventilator bevat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToestelventilatorFilterdoekKlasse'
    options = {
        'f7': KeuzelijstWaarde(invulwaarde='f7',
                               label='F7',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToestelventilatorFilterdoekKlasse/f7'),
        'g3': KeuzelijstWaarde(invulwaarde='g3',
                               label='G3',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToestelventilatorFilterdoekKlasse/g3'),
        'g4': KeuzelijstWaarde(invulwaarde='g4',
                               label='G4',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToestelventilatorFilterdoekKlasse/g4'),
        'm5': KeuzelijstWaarde(invulwaarde='m5',
                               label='M5',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToestelventilatorFilterdoekKlasse/m5'),
        'm6': KeuzelijstWaarde(invulwaarde='m6',
                               label='M6',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToestelventilatorFilterdoekKlasse/m6')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWaaierTypeOpstelling(KeuzelijstField):
    """Keuzelijst voor de verschillende types van opstelling van een waaier."""
    naam = 'KlWaaierTypeOpstelling'
    label = 'Waaier opstelling type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWaaierTypeOpstelling'
    definition = 'Keuzelijst voor de verschillende types van opstelling van een waaier.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWaaierTypeOpstelling'
    options = {
        'axiaal': KeuzelijstWaarde(invulwaarde='axiaal',
                                   label='axiaal',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWaaierTypeOpstelling/axiaal'),
        'gemengd': KeuzelijstWaarde(invulwaarde='gemengd',
                                    label='gemengd',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWaaierTypeOpstelling/gemengd'),
        'radiaal': KeuzelijstWaarde(invulwaarde='radiaal',
                                    label='radiaal',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWaaierTypeOpstelling/radiaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.Classes.Abstracten.BetonnenConstructieElement import BetonnenConstructieElement
from otlmow_model.Classes.Onderdeel.Funderingspaal import Funderingspaal


# Generated with OTLClassCreator. To modify: extend, do not edit
class Baret(BetonnenConstructieElement, Funderingspaal):
    """In de grond gevormde betonnen kolom waarbij de uitgegraven sleuf gevuld wordt met een steunvloeistof (bentonietsuspensie) waardoor ze in stand wordt gehouden. De lengte gedeeld door de breedte is gelijk aan of kleiner dan 6."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Baret'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlViscositeitKlasse(KeuzelijstField):
    """Keuzelijst voor de Viscosity Grade (VG) classificatie volgens ISO 3448."""
    naam = 'KlViscositeitKlasse'
    label = 'Viscositeit klasse'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlViscositeitKlasse'
    definition = 'Keuzelijst voor de Viscosity Grade (VG) classificatie volgens ISO 3448.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlViscositeitKlasse'
    options = {
        'iso-vg-10': KeuzelijstWaarde(invulwaarde='iso-vg-10',
                                      label='ISO VG 10',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-10'),
        'iso-vg-100': KeuzelijstWaarde(invulwaarde='iso-vg-100',
                                       label='ISO VG 100',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-100'),
        'iso-vg-1000': KeuzelijstWaarde(invulwaarde='iso-vg-1000',
                                        label='ISO VG 1000',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-1000'),
        'iso-vg-15': KeuzelijstWaarde(invulwaarde='iso-vg-15',
                                      label='ISO VG 15',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-15'),
        'iso-vg-150': KeuzelijstWaarde(invulwaarde='iso-vg-150',
                                       label='ISO VG 150',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-150'),
        'iso-vg-1500': KeuzelijstWaarde(invulwaarde='iso-vg-1500',
                                        label='ISO VG 1500',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-1500'),
        'iso-vg-2': KeuzelijstWaarde(invulwaarde='iso-vg-2',
                                     label='ISO VG 2',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-2'),
        'iso-vg-22': KeuzelijstWaarde(invulwaarde='iso-vg-22',
                                      label='ISO VG 22',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-22'),
        'iso-vg-220': KeuzelijstWaarde(invulwaarde='iso-vg-220',
                                       label='ISO VG 220',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-220'),
        'iso-vg-3': KeuzelijstWaarde(invulwaarde='iso-vg-3',
                                     label='ISO VG 3',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-3'),
        'iso-vg-32': KeuzelijstWaarde(invulwaarde='iso-vg-32',
                                      label='ISO VG 32',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-32'),
        'iso-vg-320': KeuzelijstWaarde(invulwaarde='iso-vg-320',
                                       label='ISO VG 320',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-320'),
        'iso-vg-46': KeuzelijstWaarde(invulwaarde='iso-vg-46',
                                      label='ISO VG 46',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-46'),
        'iso-vg-460': KeuzelijstWaarde(invulwaarde='iso-vg-460',
                                       label='ISO VG 460',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-460'),
        'iso-vg-5': KeuzelijstWaarde(invulwaarde='iso-vg-5',
                                     label='ISO VG 5',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-5'),
        'iso-vg-68': KeuzelijstWaarde(invulwaarde='iso-vg-68',
                                      label='ISO VG 68',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-68'),
        'iso-vg-680': KeuzelijstWaarde(invulwaarde='iso-vg-680',
                                       label='ISO VG 680',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-680'),
        'iso-vg-7': KeuzelijstWaarde(invulwaarde='iso-vg-7',
                                     label='ISO VG 7',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlViscositeitKlasse/iso-vg-7')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlElektromotorMerk(KeuzelijstField):
    """Het merk van een elektromotor."""
    naam = 'KlElektromotorMerk'
    label = 'Elektromotor merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlElektromotorMerk'
    definition = 'Het merk van een elektromotor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlElektromotorMerk'
    options = {
        'abb': KeuzelijstWaarde(invulwaarde='abb',
                                label='ABB',
                                status='ingebruik',
                                definitie='ABB',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorMerk/abb'),
        'siemens': KeuzelijstWaarde(invulwaarde='siemens',
                                    label='Siemens',
                                    status='ingebruik',
                                    definitie='Siemens',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorMerk/siemens'),
        'vem': KeuzelijstWaarde(invulwaarde='vem',
                                label='VEM',
                                status='ingebruik',
                                definitie='VEM',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorMerk/vem')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




from abc import abstractmethod, ABC

from otlmow_model.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.BaseClasses.WKTField import WKTField
from otlmow_model.GeometrieTypes.AbstracteGeometrie import AbstracteGeometrie


class LijnGeometrie(AbstracteGeometrie):
    @abstractmethod
    def __init__(self):
        super().__init__()
        self._geometry_types.append('LINESTRING Z')



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlElastischElementHardheid(KeuzelijstField):
    """Keuzelijst die de verschillende types hardheid van een elastisch element bevat."""
    naam = 'KlElastischElementHardheid'
    label = 'Elastisch element hardheid'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlElastischElementHardheid'
    definition = 'Keuzelijst die de verschillende types hardheid van een elastisch element bevat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlElastischElementHardheid'
    options = {
        'shore-64': KeuzelijstWaarde(invulwaarde='shore-64',
                                     label='Shore 64',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElastischElementHardheid/shore-64'),
        'shore-92': KeuzelijstWaarde(invulwaarde='shore-92',
                                     label='Shore 92',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElastischElementHardheid/shore-92'),
        'shore-98': KeuzelijstWaarde(invulwaarde='shore-98',
                                     label='Shore 98',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElastischElementHardheid/shore-98')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.Classes.Abstracten.AxiaalDraagvermogen import AxiaalDraagvermogen
from otlmow_model.Classes.Abstracten.AxiaalDraagvermogenWand import AxiaalDraagvermogenWand
from otlmow_model.Classes.Abstracten.Grondkeringen import Grondkeringen
from otlmow_model.Classes.Abstracten.WaterremmendeFunctie import WaterremmendeFunctie
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlPrimaireVormCombiwand import KlPrimaireVormCombiwand
from otlmow_model.Datatypes.KlSecundaireVormCombiwand import KlSecundaireVormCombiwand
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Combiwand(AxiaalDraagvermogen, AxiaalDraagvermogenWand, Grondkeringen, WaterremmendeFunctie, AIMObject):
    """Een gecombineerde wand bestaande uit verschillende damplanken en buispalen of H-profielen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker')

        self._primaireVorm = OTLAttribuut(field=KlPrimaireVormCombiwand,
                                          naam='primaireVorm',
                                          label='primaire vorm',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand.primaireVorm',
                                          definition='Keuzelijst dat de primaire vorm van de combiwand aangeeft.',
                                          owner=self)

        self._rekennotaCombiwand = OTLAttribuut(field=DtcDocument,
                                                naam='rekennotaCombiwand',
                                                label='rekennota combiwand',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand.rekennotaCombiwand',
                                                definition="De rekennota van de combiwand, met o.a. de vermelding van UGT's en GGT's.",
                                                owner=self)

        self._secundaireVorm = OTLAttribuut(field=KlSecundaireVormCombiwand,
                                            naam='secundaireVorm',
                                            label='secundaire vorm',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand.secundaireVorm',
                                            definition='Keuzelijst dat de secundaire vorm van de combiwand aangeeft.',
                                            owner=self)

        self._technischeFicheCombiwand = OTLAttribuut(field=DtcDocument,
                                                      naam='technischeFicheCombiwand',
                                                      label='technische fiche combiwand',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand.technischeFicheCombiwand',
                                                      definition='Document dat de technische details van de combiwand bijhoudt.',
                                                      owner=self)

        self._totaleLengteCombiwand = OTLAttribuut(field=KwantWrdInMeter,
                                                   naam='totaleLengteCombiwand',
                                                   label='totale lengte combiwand',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Combiwand.totaleLengteCombiwand',
                                                   definition='De totale horizontale lengte van de gehele combiwand in lopende meter.',
                                                   owner=self)

    @property
    def primaireVorm(self) -> str:
        """Keuzelijst dat de primaire vorm van de combiwand aangeeft."""
        return self._primaireVorm.get_waarde()

    @primaireVorm.setter
    def primaireVorm(self, value):
        self._primaireVorm.set_waarde(value, owner=self)

    @property
    def rekennotaCombiwand(self) -> DtcDocumentWaarden:
        """De rekennota van de combiwand, met o.a. de vermelding van UGT's en GGT's."""
        return self._rekennotaCombiwand.get_waarde()

    @rekennotaCombiwand.setter
    def rekennotaCombiwand(self, value):
        self._rekennotaCombiwand.set_waarde(value, owner=self)

    @property
    def secundaireVorm(self) -> str:
        """Keuzelijst dat de secundaire vorm van de combiwand aangeeft."""
        return self._secundaireVorm.get_waarde()

    @secundaireVorm.setter
    def secundaireVorm(self, value):
        self._secundaireVorm.set_waarde(value, owner=self)

    @property
    def technischeFicheCombiwand(self) -> DtcDocumentWaarden:
        """Document dat de technische details van de combiwand bijhoudt."""
        return self._technischeFicheCombiwand.get_waarde()

    @technischeFicheCombiwand.setter
    def technischeFicheCombiwand(self, value):
        self._technischeFicheCombiwand.set_waarde(value, owner=self)

    @property
    def totaleLengteCombiwand(self) -> KwantWrdInMeterWaarden:
        """De totale horizontale lengte van de gehele combiwand in lopende meter."""
        return self._totaleLengteCombiwand.get_waarde()

    @totaleLengteCombiwand.setter
    def totaleLengteCombiwand(self, value):
        self._totaleLengteCombiwand.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Luchtkwaliteitsensor(NaampadObject, VlakGeometrie):
    """Installatie voor het meten van verschillende aspecten van de luchtkwaliteit in tunnels tussen twee punten op basis van de onderbrekingen in een signaal dat tussen die twee punten reist."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Luchtkwaliteitsensor'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAfsluitingMerk(KeuzelijstField):
    """Het merk van een afsluiting."""
    naam = 'KlAfsluitingMerk'
    label = 'Afsluiting merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAfsluitingMerk'
    definition = 'Het merk van een afsluiting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAfsluitingMerk'
    options = {
        'bekaert': KeuzelijstWaarde(invulwaarde='bekaert',
                                    label='Bekaert',
                                    status='ingebruik',
                                    definitie='Bekaert',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfsluitingMerk/bekaert'),
        'hilfra': KeuzelijstWaarde(invulwaarde='hilfra',
                                   label='Hilfra',
                                   status='ingebruik',
                                   definitie='Hilfra',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfsluitingMerk/hilfra'),
        'horta': KeuzelijstWaarde(invulwaarde='horta',
                                  label='Horta',
                                  status='ingebruik',
                                  definitie='Horta',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfsluitingMerk/horta')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSmeringType(KeuzelijstField):
    """Keuzelijst voor de verschillende wijzen van smering van een mechanisch systeem."""
    naam = 'KlSmeringType'
    label = 'Smering type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlSmeringType'
    definition = 'Keuzelijst voor de verschillende wijzen van smering van een mechanisch systeem.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSmeringType'
    options = {
        'droog-lopend': KeuzelijstWaarde(invulwaarde='droog-lopend',
                                         label='droog lopend',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSmeringType/droog-lopend'),
        'handmatig-te-smeren': KeuzelijstWaarde(invulwaarde='handmatig-te-smeren',
                                                label='handmatig te smeren',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSmeringType/handmatig-te-smeren'),
        'met-automatische-smering': KeuzelijstWaarde(invulwaarde='met-automatische-smering',
                                                     label='met automatische smering',
                                                     status='ingebruik',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSmeringType/met-automatische-smering'),
        'zelf-smerend': KeuzelijstWaarde(invulwaarde='zelf-smerend',
                                         label='zelf smerend',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSmeringType/zelf-smerend')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeBadge(KeuzelijstField):
    """De verschillende badgetypes."""
    naam = 'KlTypeBadge'
    label = 'Type badge'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlTypeBadge'
    definition = 'De verschillende badgetypes.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeBadge'
    options = {
        'extern': KeuzelijstWaarde(invulwaarde='extern',
                                   label='extern',
                                   status='ingebruik',
                                   definitie='extern',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBadge/extern'),
        'facilitair-bedrijf': KeuzelijstWaarde(invulwaarde='facilitair-bedrijf',
                                               label='Facilitair bedrijf',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBadge/facilitair-bedrijf'),
        'specifiek': KeuzelijstWaarde(invulwaarde='specifiek',
                                      label='specifiek',
                                      status='ingebruik',
                                      definitie='specifiek',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBadge/specifiek'),
        'tunnels-antwerpen': KeuzelijstWaarde(invulwaarde='tunnels-antwerpen',
                                              label='tunnels Antwerpen',
                                              status='ingebruik',
                                              definitie='tunnels Antwerpen',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBadge/tunnels-antwerpen'),
        'vwt-net': KeuzelijstWaarde(invulwaarde='vwt-net',
                                    label='VWT-NET',
                                    status='ingebruik',
                                    definitie='VWT-NET',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBadge/vwt-net')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPLCMerk(KeuzelijstField):
    """Het merk van de PLC."""
    naam = 'KlPLCMerk'
    label = 'PLC merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlPLCMerk'
    definition = 'Het merk van de PLC.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPLCMerk'
    options = {
        'dtn': KeuzelijstWaarde(invulwaarde='dtn',
                                label='DTN',
                                status='ingebruik',
                                definitie='DTN',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPLCMerk/dtn'),
        'phoenics': KeuzelijstWaarde(invulwaarde='phoenics',
                                     label='Phoenics',
                                     status='ingebruik',
                                     definitie='Phoenics',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPLCMerk/phoenics'),
        'phoenix-contact': KeuzelijstWaarde(invulwaarde='phoenix-contact',
                                            label='Phoenix Contact',
                                            status='ingebruik',
                                            definitie='Phoenix Contact',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPLCMerk/phoenix-contact'),
        'seneca': KeuzelijstWaarde(invulwaarde='seneca',
                                   label='SENECA',
                                   status='ingebruik',
                                   definitie='SENECA',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPLCMerk/seneca'),
        'siemens': KeuzelijstWaarde(invulwaarde='siemens',
                                    label='Siemens',
                                    status='ingebruik',
                                    definitie='Siemens',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPLCMerk/siemens'),
        'vaisala': KeuzelijstWaarde(invulwaarde='vaisala',
                                    label='Vaisala',
                                    status='ingebruik',
                                    definitie='Vaisala',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPLCMerk/vaisala')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

